@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Chromatic and diatonic melodic ornamentation
 
-our $VERSION = '0.0207';
+our $VERSION = '0.0208';
 
 use Data::Dumper::Compact qw(ddc);
 use List::SomeUtils qw(first_index);
@@ -71,7 +71,6 @@ sub grace_note {
         my $i = first_index { $_ eq $pitch } @{ $self->_scale };
         $grace_note = $self->_scale->[ $i + $offset ];
     }
-    print "Grace note: $grace_note\n" if $self->verbose;
 
     my $x = $MIDI::Simple::Length{$duration} * TICKS;
     my $y = $MIDI::Simple::Length{yn} * TICKS; # Thirty-second note
@@ -80,7 +79,10 @@ sub grace_note {
     $y = 'd' . $y;
     $z = 'd' . $z;
 
-    return [ [$y, $grace_note], [$z, $pitch] ];
+    my @grace_note = ([$y, $grace_note], [$z, $pitch]);
+    print 'Grace note: ', ddc(\@grace_note) if $self->verbose;
+
+    return \@grace_note;
 }
 
 
@@ -103,7 +105,6 @@ sub turn {
         $above = $self->_scale->[ $i + $offset ];
         $below = $self->_scale->[ $i - $offset ];
     }
-    print "Above/Below: $above / $below\n" if $self->verbose;
 
     my $x = $MIDI::Simple::Length{$duration} * TICKS;
     my $z = sprintf '%0.f', $x / $number;
@@ -133,7 +134,6 @@ sub trill {
         my $i = first_index { $_ eq $pitch } @{ $self->_scale };
         $alt = $self->_scale->[ $i + $offset ];
     }
-    print "Alternate note: $alt\n" if $self->verbose;
 
     my $x = $MIDI::Simple::Length{$duration} * TICKS;
     my $z = sprintf '%0.f', ($x / $number / 2);
@@ -151,6 +151,7 @@ sub trill {
 sub mordent {
     my ($self, $duration, $pitch, $offset) = @_;
 
+    my $number = 4;
     $offset //= 1;
 
     my $alt;
@@ -163,10 +164,9 @@ sub mordent {
         my $i = first_index { $_ eq $pitch } @{ $self->_scale };
         $alt = $self->_scale->[ $i + $offset ];
     }
-    print "Alternate note: $alt\n" if $self->verbose;
 
     my $x = $MIDI::Simple::Length{$duration} * TICKS;
-    my $y = sprintf '%0.f', $x / 4;
+    my $y = sprintf '%0.f', $x / $number;
     my $z = sprintf '%0.f', $x - (2 * $y);
     print "Durations: $x, $y, $z\n" if $self->verbose;
     $y = 'd' . $y;
@@ -194,7 +194,7 @@ Music::MelodicDevice::Ornamentation - Chromatic and diatonic melodic ornamentati
 
 =head1 VERSION
 
-version 0.0207
+version 0.0208
 
 =head1 SYNOPSIS
 
